@@ -233,21 +233,23 @@ enaml wish list
 * fix freezing of linux/Ubuntu system in debugging of opening/opened PopupViews in PyCharm
   (workaround: killing of java PyCharm process).
 """
-from abc import abstractmethod, ABC
 import ast
-from copy import deepcopy
 import os
 import pathlib
+
+from abc import abstractmethod, ABC
+from copy import deepcopy
 from pprint import pformat
 from typing import Any, Callable, Dict, List, Optional, Tuple, Union
 
-from ae.base import file_content, file_write, norm_line_sep, norm_name                      # type: ignore
-from ae.core import DEBUG_LEVEL_VERBOSE                                                     # type: ignore
+from ae.base import norm_line_sep, norm_name                                                # type: ignore
+from ae.files import read_file_text, write_file_text                                        # type: ignore
 from ae.i18n import get_f_string                                                            # type: ignore
+from ae.core import DEBUG_LEVEL_VERBOSE                                                     # type: ignore
 from ae.gui_app import id_of_flow, flow_action, flow_key, replace_flow_action               # type: ignore
 
 
-__version__ = '0.1.39'
+__version__ = '0.1.40'
 
 
 FLOW_PATH_ROOT_ID = 'ROOT'  #: pseudo item id needed for flow path jumper and for drop onto leave item button
@@ -610,7 +612,7 @@ class LiszDataMixin(ABC):
         try:
             # the alternative `os.makedirs(exist_ok=True)` has problems on POSIX with '..' in the path
             pathlib.Path(file_path).mkdir(parents=True, exist_ok=True)
-            err_msg = "" if file_write(pformat(node), os.path.join(file_path, file_name)) \
+            err_msg = "" if write_file_text(pformat(node), os.path.join(file_path, file_name)) \
                 else f"export_node() error writing to file {os.path.join(file_path, file_name)}"
         except (FileExistsError, FileNotFoundError, OSError, ValueError) as ex:
             err_msg = str(ex)
@@ -810,7 +812,7 @@ class LiszDataMixin(ABC):
             if node_name.startswith(NODE_FILE_PREFIX):
                 node_name = node_name[len(NODE_FILE_PREFIX):]
 
-        content = file_content(file_path, error_handling='strict')
+        content = read_file_text(file_path, error_handling='strict')
         if content is None:
             return node_name, list(), file_path, "file load error"
 
